import Vue from 'vue'

/**
 * 数组更新试图
 * @param {*} source 原始数据 ( 从哪复制 )
 * @param {*} ari 目标数据 ( 复制到哪去 )
 */
export function vmSet (source, ari = []) {
  if (Object.prototype.toString.call(source) !== '[object Array]' || source.length < 1) return ari
  ari = []
  source.map((item, index) => {
    Vue.set(ari, index, item)
  })
  return ari
}

/**
 * 深拷贝
 * @param {*} source
 * @param {*} arrive
 */
export function deepClone (source, arrive) {
  if (!source && typeof source !== 'object') {
    throw new Error('error arguments', 'shallowClone')
  }
  const targetObj = arrive || source.constructor === Array ? [] : {}
  for (const keys in source) {
    if (source.hasOwnProperty(keys)) {
      if (source[keys] && typeof source[keys] === 'object') {
        targetObj[keys] = source[keys].constructor === Array ? [] : {}
        targetObj[keys] = deepClone(source[keys])
      } else {
        targetObj[keys] = source[keys]
      }
    }
  }
  return targetObj
}
  

/**
 * 全局注册组件
 * @param {*} slotName
 * @param {*} template
 */
export function GComponent (slotName, template) {
  if (!slotName || !template) return
  Vue.component(slotName, {
    template: `` + template
  })
}

/**
 * 全局注册组件
 * @param {*} slotName
 * @param {*} template
 */
export function GCompile (template) {
  if (!template) return
  return Vue.compile(template + ``)
}

/**
 * 全局注册指令
 * @param {*} param0
 */
export function GDirective ({ name }) {
  Vue.directive(name, {
    bind (el, binding, vnode) {
      const dirs = binding.value
      if (!dirs || dirs.length < 1) return
      dirs.map(item => {
        el.addEventListener(item.handleName || 'click', e => {
          console.log('binding: ', binding)
          item.handle && item.handle({ el, binding, vnode })
          eval(item.eval)
        }, false)
      })
    }
  })
}

/**
 * 格式化json为字符串
 * @param {*} msg
 */
export function formatJson (json) {
  var rep = '~'
  var jsonStr = JSON.stringify(json, null, rep)
  var str = ''
  for (var i = 0; i < jsonStr.length; i++) {
    var text2 = jsonStr.charAt(i)
    if (i > 1) {
      var text = jsonStr.charAt(i - 1)
      if (rep != text && rep == text2) {
          str += "<br/>"
      }
    }
    str += text2
  }
  jsonStr = ''
  for (var i = 0; i < str.length; i++) {
    var text = str.charAt(i)
    if (rep == text)
      jsonStr += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;"
    else {
      jsonStr += text
    }
    if (i == str.length - 2) jsonStr += "<br/>"
  }
  return jsonStr
}

/**
 * 以new vue 的方式去渲染动态模板
 */
export function renderTemplate (el, template) {
  const vm = new Vue({
    el: el,
    template: template
  })
  setTimeout(() => vm.destroy(), 0)
}

/**
 * 删除判断
 * @param {*} title
 * @param {*} callback
 */
export function handleDelete (title, callback) {
  const _title = title || '此操作将永久删除, 是否继续?'
  Vue.prototype.$confirm(_title, '提示', {
    confirmButtonText: '确定',
    cancelButtonText: '取消',
    type: 'warning'
  }).then(() => {
    if (typeof callback === 'function') {
      callback()
    }
  }).catch(() => {
    Vue.prototype.$message({
      type: 'info',
      message: '已取消'
    })
  })
}
