'use strict'
import axios from 'axios'
import store from '@/store'
import qs from 'qs'
import { loadOpen, loadClose } from '@/utils/message'

// init
const service = axios.create({
  timeout: 5000
})
// request
service.interceptors.request.use(config => {
  // Do something before request is sent
  if (store.getters.token) {
    config.headers['X-Token'] = ''
  }
  return config
  }, error => {
    console.log(error)
    Promise.reject(error)
  })
// response
service.interceptors.response.use(
  (response) => {
    loadClose()
    const json = response.data
    // 如果未登录 后台返回登录页字符串
    if (json.data && !json.data.success) {
      // Message.warning(json.data.msg)
    }
    return json
  },
  error => {
    loadClose()
    return Promise.reject(error)
})
  
// ajax entry
const suffix = '' // 后缀
const ajax = function (obj) {
  if (obj.mock) return service.get(obj.url)

  loadOpen()
  const _suffix = obj.suffix || suffix
  let source = obj.source || 'System/ToolkitVue'
  let url = obj.url + _suffix + '?Source=' + source
  let type = obj.type ? obj.type.toUpperCase() : 'GET'
  const headers = { headers: { 'Content-Type': 'application/json' }}
  // let params = validArray(obj.params || {})
  let params = obj.params || {}
  // 拼接url或数据
  switch (type) {
    case 'GET':
      url += ('&type=' + obj.apiType)
      return service.get(url, { params: params })
    case 'POST':
      url += ('&type=' + obj.apiType)
      return service.post(url, params, headers)
    case 'PUT': return service.put(url, params, headers)
    case 'DELETE': return service.delete(url, params, headers)
    default: break
  }
}

// 转Array为字符串
function validArray (params, type) {
  if (Object.keys(params).length < 1) return
  for (const key in params) {
    const item = params[key]
    if (item && Object.prototype.toString.call(item) === '[object Array]') { // 数组对象
      params[key] = item.map(o => validArray(o))
    }
    if (item && Object.prototype.toString.call(item) === '[object Object]') { // json对象
      params[key] = validArray(item)
    }
    if (item !== 0 && !item) params[key] = ''
  }
  params = JSON.stringify(params)
  console.log('params: ', params)
  return params
}

export default ajax